==> schluessel-0.3.2-src.zip: schluessel/src/net/morilib/lisp/subr/Magnitude.java <==
/*
 * Copyright 2009 Yuichiro Moriguchi
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package net.morilib.lisp.subr;

import net.morilib.lisp.Datum;
import net.morilib.lisp.Environment;
import net.morilib.lisp.LispMessage;
import net.morilib.lisp.LispNumber;

/**
 * 
 *
 *
 * @author MORIGUCHI, Yuichiro 2009
 */
public class Magnitude extends UnaryArgs {

	/* (non-Javadoc)
	 * @see net.morilib.lisp.subr.UnaryArgs#execute(net.morilib.lisp.Datum, net.morilib.lisp.Environment, net.morilib.lisp.LispMessage)
	 */
	@Override
	protected Datum execute(Datum c1a, Environment env, LispMessage mesg) {
		if(c1a instanceof LispNumber) {
//			LispNumber n = (LispNumber)c1a;
//
//			if(n.isReal()) {
//				LispReal r = (LispReal)n;
//
//				return (r.signum() < 0) ? r.uminus() : r;
//			} else {
//				double r = n.getRealDouble();
//				double i = n.getImagDouble();
//
//				return new LispDouble(Math.hypot(r, i));
//			}
			return ((LispNumber)c1a).norm();
		} else {
			throw mesg.getError("err.require.number", c1a);
		}
	}

}

==> schluessel-0.4.3-src.zip: schluessel/src/net/morilib/lisp/subr/Magnitude.java <==
/*
 * Copyright 2009 Yuichiro Moriguchi
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package net.morilib.lisp.subr;

import net.morilib.lisp.Datum;
import net.morilib.lisp.Environment;
import net.morilib.lisp.LispMessage;
import net.morilib.lisp.math.algebra.ILispNorm;

/**
 * 
 *
 *
 * @author MORIGUCHI, Yuichiro 2009
 */
public class Magnitude extends UnaryArgs {

	/* (non-Javadoc)
	 * @see net.morilib.lisp.subr.UnaryArgs#execute(net.morilib.lisp.Datum, net.morilib.lisp.Environment, net.morilib.lisp.LispMessage)
	 */
	@Override
	protected Datum execute(Datum c1a, Environment env, LispMessage mesg) {
		if(c1a instanceof ILispNorm) {
//			LispNumber n = (LispNumber)c1a;
//
//			if(n.isReal()) {
//				LispReal r = (LispReal)n;
//
//				return (r.signum() < 0) ? r.uminus() : r;
//			} else {
//				double r = n.getRealDouble();
//				double i = n.getImagDouble();
//
//				return new LispDouble(Math.hypot(r, i));
//			}
			return ((ILispNorm)c1a).norm();
		} else {
			throw mesg.getError("err.require.number", c1a);
		}
	}

}
